@@ -7,13 +7,19 @@
     :license: MIT, see LICENSE for more details.
 """
 
-__version__ = '0.4.0'
+__version__ = '0.5.0'
 
-from .entropy import random_secret_exponent
-from .passphrase import random_256bit_passphrase, random_160bit_passphrase
 from .b58check import b58check_encode, b58check_decode, b58check_unpack, \
 	b58check_version_byte, is_b58check
-from .utils import is_secret_exponent, is_256bit_hex_string, \
-    is_wif_pk, is_b58check_address, extract_pk_as_int
+from .entropy import random_secret_exponent
+from .formatcheck import *
+from .hash160 import Hash160, bin_hash160 
+from .keypair import *
+from .passphrase import random_256bit_passphrase, random_160bit_passphrase
+from .privatekey import *
+from .publickey import *
+from .wallet import SDWallet
+
+
+
 
-from .keypair import *
\ No newline at end of file
